@@ -27,8 +27,6 @@
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kglobalsettings.h>
-#include <klocale.h>
-#include <klocalizedstring.h>
 
 #include "x11_helper.h"
 #include "xinput_helper.h"
